.. include:: ../references.txt

.. _gamma_ray_analysis:


Gamma-ray data analysis
=======================

TODO: write a short introduction to gamma-ray data analysis.

See e.g. [Berge2007]_, [Cash1979]_, [LiMa1983]_ and [Mohrmann2019]_.